timesignaturetools.fit_metrical_hierarchies_to_expr
===================================================

.. autofunction:: abjad.tools.timesignaturetools.fit_metrical_hierarchies_to_expr.fit_metrical_hierarchies_to_expr
   :noindex:
